# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: colabo/flow/go/go.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='colabo/flow/go/go.proto',
  package='colabo.flow',
  syntax='proto3',
  serialized_options=None,
  serialized_pb=_b('\n\x17\x63olabo/flow/go/go.proto\x12\x0b\x63olabo.flow\"%\n\x13\x46lowInstanceRequest\x12\x0e\n\x06\x66lowId\x18\x02 \x01(\t\"\x1f\n\x11\x46lowInstanceReply\x12\n\n\x02id\x18\x01 \x01(\t\"\x9d\x01\n\x14\x41\x63tionExecuteRequest\x12\x0e\n\x06\x66lowId\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x16\n\x0e\x66lowInstanceId\x18\x03 \x01(\t\x12\x0e\n\x06\x64\x61taIn\x18\x04 \x01(\t\x12\x0e\n\x06params\x18\x05 \x01(\t\x12\x18\n\x10implementationId\x18\x36 \x01(\t\x12\x15\n\rimplementerId\x18\x37 \x01(\t\"A\n\x12\x41\x63tionExecuteReply\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0f\n\x07\x64\x61taOut\x18\x02 \x01(\t\x12\x0e\n\x06params\x18\x03 \x01(\t2d\n\x0b\x41\x63tionsHost\x12U\n\rexecuteAction\x12!.colabo.flow.ActionExecuteRequest\x1a\x1f.colabo.flow.ActionExecuteReply\"\x00\x32\xbf\x01\n\tFlowsHost\x12W\n\x11startFlowInstance\x12 .colabo.flow.FlowInstanceRequest\x1a\x1e.colabo.flow.FlowInstanceReply\"\x00\x12Y\n\x11\x65xecuteActionSync\x12!.colabo.flow.ActionExecuteRequest\x1a\x1f.colabo.flow.ActionExecuteReply\"\x00\x62\x06proto3')
)




_FLOWINSTANCEREQUEST = _descriptor.Descriptor(
  name='FlowInstanceRequest',
  full_name='colabo.flow.FlowInstanceRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='flowId', full_name='colabo.flow.FlowInstanceRequest.flowId', index=0,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=40,
  serialized_end=77,
)


_FLOWINSTANCEREPLY = _descriptor.Descriptor(
  name='FlowInstanceReply',
  full_name='colabo.flow.FlowInstanceReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='colabo.flow.FlowInstanceReply.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=79,
  serialized_end=110,
)


_ACTIONEXECUTEREQUEST = _descriptor.Descriptor(
  name='ActionExecuteRequest',
  full_name='colabo.flow.ActionExecuteRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='flowId', full_name='colabo.flow.ActionExecuteRequest.flowId', index=0,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='colabo.flow.ActionExecuteRequest.name', index=1,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='flowInstanceId', full_name='colabo.flow.ActionExecuteRequest.flowInstanceId', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='dataIn', full_name='colabo.flow.ActionExecuteRequest.dataIn', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='params', full_name='colabo.flow.ActionExecuteRequest.params', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='implementationId', full_name='colabo.flow.ActionExecuteRequest.implementationId', index=5,
      number=54, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='implementerId', full_name='colabo.flow.ActionExecuteRequest.implementerId', index=6,
      number=55, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=113,
  serialized_end=270,
)


_ACTIONEXECUTEREPLY = _descriptor.Descriptor(
  name='ActionExecuteReply',
  full_name='colabo.flow.ActionExecuteReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='colabo.flow.ActionExecuteReply.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='dataOut', full_name='colabo.flow.ActionExecuteReply.dataOut', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='params', full_name='colabo.flow.ActionExecuteReply.params', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=272,
  serialized_end=337,
)

DESCRIPTOR.message_types_by_name['FlowInstanceRequest'] = _FLOWINSTANCEREQUEST
DESCRIPTOR.message_types_by_name['FlowInstanceReply'] = _FLOWINSTANCEREPLY
DESCRIPTOR.message_types_by_name['ActionExecuteRequest'] = _ACTIONEXECUTEREQUEST
DESCRIPTOR.message_types_by_name['ActionExecuteReply'] = _ACTIONEXECUTEREPLY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

FlowInstanceRequest = _reflection.GeneratedProtocolMessageType('FlowInstanceRequest', (_message.Message,), dict(
  DESCRIPTOR = _FLOWINSTANCEREQUEST,
  __module__ = 'colabo.flow.go.go_pb2'
  # @@protoc_insertion_point(class_scope:colabo.flow.FlowInstanceRequest)
  ))
_sym_db.RegisterMessage(FlowInstanceRequest)

FlowInstanceReply = _reflection.GeneratedProtocolMessageType('FlowInstanceReply', (_message.Message,), dict(
  DESCRIPTOR = _FLOWINSTANCEREPLY,
  __module__ = 'colabo.flow.go.go_pb2'
  # @@protoc_insertion_point(class_scope:colabo.flow.FlowInstanceReply)
  ))
_sym_db.RegisterMessage(FlowInstanceReply)

ActionExecuteRequest = _reflection.GeneratedProtocolMessageType('ActionExecuteRequest', (_message.Message,), dict(
  DESCRIPTOR = _ACTIONEXECUTEREQUEST,
  __module__ = 'colabo.flow.go.go_pb2'
  # @@protoc_insertion_point(class_scope:colabo.flow.ActionExecuteRequest)
  ))
_sym_db.RegisterMessage(ActionExecuteRequest)

ActionExecuteReply = _reflection.GeneratedProtocolMessageType('ActionExecuteReply', (_message.Message,), dict(
  DESCRIPTOR = _ACTIONEXECUTEREPLY,
  __module__ = 'colabo.flow.go.go_pb2'
  # @@protoc_insertion_point(class_scope:colabo.flow.ActionExecuteReply)
  ))
_sym_db.RegisterMessage(ActionExecuteReply)



_ACTIONSHOST = _descriptor.ServiceDescriptor(
  name='ActionsHost',
  full_name='colabo.flow.ActionsHost',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=339,
  serialized_end=439,
  methods=[
  _descriptor.MethodDescriptor(
    name='executeAction',
    full_name='colabo.flow.ActionsHost.executeAction',
    index=0,
    containing_service=None,
    input_type=_ACTIONEXECUTEREQUEST,
    output_type=_ACTIONEXECUTEREPLY,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_ACTIONSHOST)

DESCRIPTOR.services_by_name['ActionsHost'] = _ACTIONSHOST


_FLOWSHOST = _descriptor.ServiceDescriptor(
  name='FlowsHost',
  full_name='colabo.flow.FlowsHost',
  file=DESCRIPTOR,
  index=1,
  serialized_options=None,
  serialized_start=442,
  serialized_end=633,
  methods=[
  _descriptor.MethodDescriptor(
    name='startFlowInstance',
    full_name='colabo.flow.FlowsHost.startFlowInstance',
    index=0,
    containing_service=None,
    input_type=_FLOWINSTANCEREQUEST,
    output_type=_FLOWINSTANCEREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='executeActionSync',
    full_name='colabo.flow.FlowsHost.executeActionSync',
    index=1,
    containing_service=None,
    input_type=_ACTIONEXECUTEREQUEST,
    output_type=_ACTIONEXECUTEREPLY,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_FLOWSHOST)

DESCRIPTOR.services_by_name['FlowsHost'] = _FLOWSHOST

# @@protoc_insertion_point(module_scope)
